==> texinfo-4.13.90.tar.xz: texinfo-4.13.90/tp/t/results/macro/recursive_call_in_macro.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text);

use utf8;

$result_trees{'recursive_call_in_macro'} = {
  'contents' => [
    {
      'args' => [
        {
          'parent' => {},
          'text' => 'anorecurse',
          'type' => 'macro_name'
        },
        {
          'parent' => {},
          'text' => 'arg',
          'type' => 'macro_arg'
        }
      ],
      'cmdname' => 'macro',
      'contents' => [
        {
          'parent' => {},
          'text' => '@anorecurse{arg}',
          'type' => 'raw'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'last_raw_newline'
        }
      ],
      'extra' => {
        'arg_line' => ' anorecurse{arg}
',
        'args_index' => {
          'arg' => 0
        },
        'macrobody' => '@anorecurse{arg}
',
        'spaces_after_command' => {
          'extra' => {
            'command' => {}
          },
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line_after_command'
        }
      },
      'line_nr' => {
        'file_name' => '',
        'line_nr' => 1,
        'macro' => ''
      },
      'parent' => {}
    },
    {},
    {
      'parent' => {},
      'text' => '
',
      'type' => 'empty_line'
    },
    {
      'parent' => {},
      'text' => '
',
      'type' => 'empty_line'
    }
  ],
  'type' => 'text_root'
};
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'recursive_call_in_macro'};
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'parent'} = $result_trees{'recursive_call_in_macro'};
$result_trees{'recursive_call_in_macro'}{'contents'}[1] = $result_trees{'recursive_call_in_macro'}{'contents'}[0]{'extra'}{'spaces_after_command'};
$result_trees{'recursive_call_in_macro'}{'contents'}[2]{'parent'} = $result_trees{'recursive_call_in_macro'};
$result_trees{'recursive_call_in_macro'}{'contents'}[3]{'parent'} = $result_trees{'recursive_call_in_macro'};

$result_texis{'recursive_call_in_macro'} = '@macro anorecurse{arg}
@anorecurse{arg}
@end macro


';


$result_texts{'recursive_call_in_macro'} = '

';

$result_errors{'recursive_call_in_macro'} = [
  {
    'error_line' => ':5: Recursive call of macro anorecurse is not allowed; use @rmacro if needed (possibly involving @anorecurse)
',
    'file_name' => '',
    'line_nr' => 5,
    'macro' => 'anorecurse',
    'text' => 'Recursive call of macro anorecurse is not allowed; use @rmacro if needed',
    'type' => 'error'
  }
];


1;

==> texinfo-5.1.tar.xz: texinfo-5.1/tp/t/results/macro/recursive_call_in_macro.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text);

use utf8;

$result_trees{'recursive_call_in_macro'} = {
  'contents' => [
    {
      'args' => [
        {
          'parent' => {},
          'text' => 'anorecurse',
          'type' => 'macro_name'
        },
        {
          'parent' => {},
          'text' => 'arg',
          'type' => 'macro_arg'
        }
      ],
      'cmdname' => 'macro',
      'contents' => [
        {
          'parent' => {},
          'text' => '@anorecurse{arg}',
          'type' => 'raw'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'last_raw_newline'
        }
      ],
      'extra' => {
        'arg_line' => ' anorecurse{arg}
',
        'args_index' => {
          'arg' => 0
        },
        'macrobody' => '@anorecurse{arg}
',
        'spaces_after_command' => {
          'extra' => {
            'command' => {}
          },
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line_after_command'
        }
      },
      'line_nr' => {
        'file_name' => '',
        'line_nr' => 1,
        'macro' => ''
      },
      'parent' => {}
    },
    {},
    {
      'parent' => {},
      'text' => '
',
      'type' => 'empty_line'
    },
    {
      'parent' => {},
      'text' => '
',
      'type' => 'empty_line'
    }
  ],
  'type' => 'text_root'
};
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'recursive_call_in_macro'}{'contents'}[0];
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'recursive_call_in_macro'};
$result_trees{'recursive_call_in_macro'}{'contents'}[0]{'parent'} = $result_trees{'recursive_call_in_macro'};
$result_trees{'recursive_call_in_macro'}{'contents'}[1] = $result_trees{'recursive_call_in_macro'}{'contents'}[0]{'extra'}{'spaces_after_command'};
$result_trees{'recursive_call_in_macro'}{'contents'}[2]{'parent'} = $result_trees{'recursive_call_in_macro'};
$result_trees{'recursive_call_in_macro'}{'contents'}[3]{'parent'} = $result_trees{'recursive_call_in_macro'};

$result_texis{'recursive_call_in_macro'} = '@macro anorecurse{arg}
@anorecurse{arg}
@end macro


';


$result_texts{'recursive_call_in_macro'} = '

';

$result_errors{'recursive_call_in_macro'} = [
  {
    'error_line' => ':5: recursive call of macro anorecurse is not allowed; use @rmacro if needed (possibly involving @anorecurse)
',
    'file_name' => '',
    'line_nr' => 5,
    'macro' => 'anorecurse',
    'text' => 'recursive call of macro anorecurse is not allowed; use @rmacro if needed',
    'type' => 'error'
  }
];


1;
